@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkGenericProbeFilter extends vtkDataSetAlgorithm
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkGenericProbeFilter extends vtkDataSetAlgorithm
 
     if (temp == 0) return null;
     return (vtkGenericDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetValidPoints_4();
   public vtkIdTypeArray GetValidPoints() {
@@ -33,7 +33,7 @@ public class vtkGenericProbeFilter extends vtkDataSetAlgorithm
 
     if (temp == 0) return null;
     return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   public vtkGenericProbeFilter() { super(); }
 
